@@ -2,7 +2,7 @@
  *
  * Translate local characterset to and from utf8.
  *
- * $Id: charset.c,v 1.7 2001/04/05 16:16:32 nisse Exp $
+ * $Id: charset.c,v 1.8 2002/08/27 16:43:44 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -171,7 +171,7 @@ struct lsh_string *low_utf8_to_local(UINT32 length, UINT8 *s, int strict)
 	case -1:
 	  assert(i<=res->length);
 	  
-	  res->length = i;
+	  lsh_string_trunc(res, i);
 
 	  return res;
 
