@@ -2,7 +2,7 @@
  *
  *
  *
- * $Id: client.h,v 1.47 2001/09/27 06:33:10 nisse Exp $ */
+ * $Id: client.h,v 1.49 2001/12/12 18:37:54 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -100,6 +100,9 @@ make_exec_request(struct lsh_string *command);
 struct command *
 make_pty_request(struct interact *tty);
 
+struct command *
+make_subsystem_request(struct lsh_string *subsystem);
+
 extern struct channel_open channel_open_x11;
 
 struct command *
@@ -114,7 +117,7 @@ make_client_x11_display(const char *display, struct lsh_string *fake);
      (name client_options)
      (vars
        ;; Used only by lsh, NULL for lshg.
-       (random object randomness_with_poll)
+       (random object randomness)
 
        (tty object interact)
 
@@ -163,7 +166,7 @@ make_client_x11_display(const char *display, struct lsh_string *fake);
 
 void
 init_client_options(struct client_options *options,
-		    struct randomness_with_poll *random,
+		    struct randomness *random,
 		    struct exception_handler *handler,
 		    int *exit_code);
 
