@@ -1,6 +1,6 @@
 /* client_pty.c
  *
- * $Id: client_pty.c,v 1.21 2001/09/27 06:33:36 nisse Exp $ */
+ * $Id: client_pty.c,v 1.22 2002/03/14 15:35:08 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -146,11 +146,11 @@ do_pty_continuation(struct command_continuation *s,
 	     "Setting the attributes of the local terminal failed.\n");
     }
 
-  REMEMBER_RESOURCE(channel->resources,
+  remember_resource(channel->resources,
 		    make_client_tty_resource(self->req->tty,
 					     self->req->attr));
   
-  REMEMBER_RESOURCE(channel->resources,
+  remember_resource(channel->resources,
 		    INTERACT_WINDOW_SUBSCRIBE
 		    (self->req->tty,
 		     make_client_winch_handler(channel)));
