@@ -3,7 +3,7 @@
  * Derived from
  * http://www.zip.com.au/~raf2/lib/software/daemon
  *
- * $Id: daemon.c,v 1.5 1999/12/31 00:44:26 nisse Exp $
+ * $Id: daemon.c,v 1.8 2002/08/26 20:14:18 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -88,8 +88,8 @@ int daemon_pidfile(const char *name)
     {
       if (errno != EEXIST)
 	{
-	  werror("Failed to open pid file '%z' (errno = %i): %z\n",
-		 name, errno, STRERROR(errno));
+	  werror("Failed to open pid file '%z' %e\n",
+		 name, errno);
 	  return 0;
 	}
 
@@ -118,8 +118,8 @@ int daemon_pidfile(const char *name)
       fd = open(name, O_RDONLY);
       if (fd < 0)
 	{
-	  werror("Pid file '%z' already exists, and is unreadable (errno = %i): %z\n",
-		 name, errno, STRERROR(errno));
+	  werror("Pid file '%z' already exists, and is unreadable %e\n",
+		 name, errno);
 	  return 0;
 	}
       {
@@ -132,14 +132,14 @@ int daemon_pidfile(const char *name)
 	
 	if (length < 0)
 	  {
-	    werror("Pid file '%z' already exists, but read() failed (errno = %i): %z\n",
-		   name, errno, STRERROR(errno));
+	    werror("Pid file '%z' already exists, but read failed %e\n",
+		   name, errno);
 	    return 0;
 	  }
 	if ( !length|| !buffer[0] || (length == BUF_SIZE) )
 	  {
-	    werror("Pid file '%z' already exists, but contents is garbled (errno = %i): %z\n",
-		   name, errno, STRERROR(errno));
+	    werror("Pid file '%z' already exists, but contents is garbled.\n",
+		   name);
 	    return 0;
 	  }
 
@@ -157,8 +157,8 @@ int daemon_pidfile(const char *name)
 	  if ( (errno == ERANGE) || (end != buffer + length)
 	       || (other <= 0) || (other != (pid_t) other))
 	    {
-	      werror("Pid file '%z' already exists, but contents is garbled (errno = %i): %z\n",
-		     name, errno, STRERROR(errno));
+	      werror("Pid file '%z' already exists, but contents is garbled.\n",
+		     name);
 	      return 0;
 	    }
 
@@ -191,13 +191,12 @@ int daemon_pidfile(const char *name)
 	  lsh_string_free(pid);
 	  return 1;
 	}
-      werror("Writing pid file '%z' failed (errno = %i): %z",
-	     name, errno, STRERROR(errno));
+      werror("Writing pid file '%z' failed %e\n", name, errno);
 
       /* Attempt unlinking file */
       if (unlink(name) < 0)
-	werror("Unlinking pid file '%z' failed (errno = %i): %z",
-	       name, errno, STRERROR(errno));
+	werror("Unlinking pid file '%z' failed %e\n",
+	       name, errno);
       
       lsh_string_free(pid);
 	  
@@ -230,7 +229,8 @@ int daemon_started_by_init(void)
 
 /* FIXME: Do we need to detect if the socket is listening or connected
  * to a peer? */
-int daemon_started_by_inetd(void)
+int
+daemon_started_by_inetd(void)
 {
   int optval;
   socklen_t optlen = sizeof(optval);
@@ -239,7 +239,8 @@ int daemon_started_by_inetd(void)
 }
 
 /* Disable core files */
-int daemon_disable_core(void)
+int
+daemon_disable_core(void)
 {
   struct rlimit limit = { 0, 0 };
 
@@ -327,7 +328,7 @@ int daemon_init(void)
       */
 
       if (setsid() < 0)
-	fatal("daemon_init: setsid() failed.\n");
+	fatal("daemon_init: setsid failed.\n");
 
       /* This should not be needed. All potential tty:s should be
        * opened with O_NOCTTY. FIXME: What if a user links, say,
@@ -473,8 +474,8 @@ int daemon_close(const char *name)
 {
   if (unlink(name) < 0)
     {
-      werror("daemon_close: Unlink of pid file '%z' failed (errno = %i): %z\n",
-	     name, errno, STRERROR(errno));
+      werror("daemon_close: Unlink of pid file '%z' failed %e\n",
+	     name, errno);
       return 0;
     }
   return 1;
