@@ -1,6 +1,6 @@
 /* digits.h
  *
- * $Id: digits.c,v 1.5 2000/09/01 13:36:03 nisse Exp $ */
+ * $Id: digits.c,v 1.7 2002/08/27 16:44:16 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -24,6 +24,7 @@
 #include "digits.h"
 
 #include "digit_table.h"
+#include "format.h"
 #include "werror.h"
 #include "xalloc.h"
 
@@ -128,12 +129,6 @@ decode_base64(UINT32 length, const UINT8 *in)
 	  out->data[j++] = digit;
 	}
     }
-  out->length = j;
+  lsh_string_trunc(out, j);
   return out;
 }
-      
-struct lsh_string *
-simple_decode_base64(const unsigned char *in)
-{
-  return decode_base64(strlen(in), in);
-}
