@@ -2,7 +2,7 @@
  *
  *
  *
- * $Id: encrypt.c,v 1.22 2000/06/26 20:33:51 nisse Exp $ */
+ * $Id: encrypt.c,v 1.24 2002/01/21 00:05:05 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -37,7 +37,7 @@
      (name packet_encrypt)
      (super abstract_write_pipe)
      (vars
-       (sequence_number simple UINT32)
+       (sequence_number . UINT32)
        (connection object ssh_connection)))
 */
 
@@ -64,9 +64,9 @@ do_encrypt(struct abstract_write *w,
     UINT8 s[4];
     WRITE_UINT32(s, closure->sequence_number);
 
-    HASH_UPDATE(connection->send_mac, 4, s);
-    HASH_UPDATE(connection->send_mac, packet->length, packet->data);
-    HASH_DIGEST(connection->send_mac, mac);
+    MAC_UPDATE(connection->send_mac, 4, s);
+    MAC_UPDATE(connection->send_mac, packet->length, packet->data);
+    MAC_DIGEST(connection->send_mac, mac);
   }
   lsh_string_free(packet);
 
