@@ -2,7 +2,7 @@
  *
  *
  *
- * $Id: format.c,v 1.46 2002/04/03 21:57:04 _cvs_pont Exp $ */
+ * $Id: format.c,v 1.48 2002/08/27 16:44:30 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -609,6 +609,17 @@ lsh_get_cstring(const struct lsh_string *s)
   return (s && !memchr(s->data, '\0', s->length) ? s->data : NULL);
 }
 
+struct lsh_string *
+lsh_string_trunc(struct lsh_string *s, UINT32 length)
+{
+  assert(length <= s->length);
+  s->length = length;
+  /* NUL-terminate */
+  s->data[length] = 0;
+
+  return s;
+}
+
 int
 lsh_string_eq(const struct lsh_string *a, const struct lsh_string *b)
 {
@@ -712,8 +723,8 @@ lsh_string_bubblebabble(struct lsh_string *s, int freeflag)
 
   char vowels[6] = { 'a', 'e', 'i', 'o', 'u', 'y' };
 
-  char cons[18] = { 'b', 'c', 'd', 'f', 'g', 'h', 'k',  'l', 'm',
-		    'n', 'p', 'r', 's', 't', 'v', 'w', 'x' }; 
+  char cons[17] = { 'b', 'c', 'd', 'f', 'g', 'h', 'k',  'l', 'm',
+		    'n', 'p', 'r', 's', 't', 'v', 'z', 'x' }; 
   
   *r++ = 'x';
   
