@@ -1,6 +1,6 @@
 /* gateway_channel.h
  *
- * $Id: gateway_channel.h,v 1.2 2000/08/03 23:47:11 nisse Exp $
+ * $Id: gateway_channel.h,v 1.5 2002/08/25 08:14:44 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -26,7 +26,6 @@
 #define LSH_GATEWAY_CHANNEL_H_INCLUDED
 
 #include "channel.h"
-#include "command.h"
 
 #define GABA_DECLARE
 #include "gateway_channel.h.x"
@@ -44,19 +43,18 @@ struct gateway_channel *
 make_gateway_channel(struct alist *request_types);
 
 struct command *
-make_gateway_channel_open_command(int type,
-				  UINT32 rec_window_size,
-				  UINT32 rec_max_packet,
+make_gateway_channel_open_command(struct channel_open_info *info,
 				  struct lsh_string *args,
 				  struct alist *requests);
 
 struct command_continuation *
 make_gateway_channel_open_continuation(struct command_continuation *up,
+				       struct channel_request *fallback,
 				       struct gateway_channel *origin);
 
 extern struct channel_request gateway_channel_request;
 extern struct global_request gateway_global_request;
 
-#endif /* LSH_GATEWAY_CHANNEL_H_INCLUDED */
+extern struct channel_open gateway_channel_open_forward;
 
- 
+#endif /* LSH_GATEWAY_CHANNEL_H_INCLUDED */
