@@ -1,6 +1,6 @@
 /* gateway_commands.h
  *
- * $Id: gateway_commands.h,v 1.1 2000/11/14 17:18:53 nisse Exp $
+ * $Id: gateway_commands.h,v 1.3 2002/08/25 08:17:09 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -25,18 +25,18 @@
 #ifndef GATEWAY_COMMANDS_H_INCLUDED
 #define GATEWAY_COMMANDS_H_INCLUDED
 
-#include "command.h"
+#include "io.h"
 
 extern struct command gateway_init;
 #define GATEWAY_INIT (&gateway_init.super)
 
-extern struct command_simple gateway_accept;
+extern struct command_2 gateway_accept;
 #define GATEWAY_ACCEPT (&gateway_accept.super.super)
 
 struct command *
-make_gateway_setup(struct command *listen);
+make_gateway_setup(struct local_info *local);
 
-extern struct command_simple gateway_setup_command;
-#define GATEWAY_SETUP (&gateway_setup_command.super.super)
+extern struct command gateway_setup_command;
+#define GATEWAY_SETUP (&gateway_setup_command.super)
 
 #endif /* GATEWAY_COMMANDS_H_INCLUDED */
