@@ -1,6 +1,6 @@
 /* handshake.c
  *
- * $Id: handshake.c,v 1.12 2002/03/14 13:08:53 nisse Exp $
+ * $Id: handshake.c,v 1.14 2002/08/25 08:14:44 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -24,6 +24,7 @@
 
 #include "handshake.h"
 
+#include "command.h"
 #include "compress.h"
 #include "connection.h"
 #include "debug.h"
@@ -376,7 +377,7 @@ DEFINE_COMMAND4(handshake_command)
   
   connection = make_ssh_connection
     (info->flags,
-     lv->peer, info->debug_comment, 
+     lv->peer, lv->local, info->debug_comment, 
      make_exc_finish_read_handler(lv->fd, e, HANDLER_CONTEXT));
 
   connection_after_keyexchange(connection, c);
