@@ -1,6 +1,6 @@
 /* io.c
  *
- * $Id: io.c,v 1.168 2002/06/26 16:00:40 nisse Exp $ */
+ * $Id: io.c,v 1.175 2002/08/27 16:45:00 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -23,6 +23,7 @@
 
 #include "io.h"
 
+#include "command.h"
 #include "format.h"
 #include "string_buffer.h"
 #include "werror.h"
@@ -332,8 +333,7 @@ io_run(void)
   /* We need liboop-0.8, OOP_ERROR is not defined in liboop-0.7. */
 
   if (res == OOP_ERROR)
-    werror("oop_sys_run (errno = %i):  %z\n",
-	   errno, STRERROR(errno));
+    werror("oop_sys_run %e\n", errno);
 
   trace("io_run: Exiting\n");
 }
@@ -587,7 +587,7 @@ do_consuming_read(struct io_callback *c,
 	}
       else if (res > 0)
 	{
-	  s->length = res;
+	  lsh_string_trunc(s, res);
 	  A_WRITE(self->consumer, s);
 	}
       else
@@ -659,7 +659,7 @@ do_write_callback(struct io_callback *s UNUSED,
 		 && (fd->write_buffer->length == 1) )
 	      debug("io.c: ignoring write error, on the final ^D character\n");
 #endif
-	    werror("io.c: write failed, %z\n", STRERROR(errno));
+	    werror("io.c: write failed %e\n", errno);
 	    EXCEPTION_RAISE(fd->e,
 			    make_io_exception(EXC_IO_WRITE,
 					      fd, errno, NULL));
@@ -698,7 +698,7 @@ make_listen_value(struct lsh_fd *fd,
      (name io_listen_callback)
      (super io_callback)
      (vars
-       (c object command_continuation)
+       (c object command)
        (e object exception_handler)))
 */
 
@@ -721,20 +721,21 @@ do_listen_callback(struct io_callback *s,
 		(struct sockaddr *) &peer, &addr_len);
   if (conn < 0)
     {
-      werror("io.c: accept failed, %z", STRERROR(errno));
+      werror("io.c: accept failed %e", errno);
       return;
     }
 
   trace("io.c: accept on fd %i\n", conn);
-  COMMAND_RETURN(self->c,
-		 make_listen_value(make_lsh_fd(conn, "accepted socket", self->e),
-				   sockaddr2info(addr_len,
-						 (struct sockaddr *) &peer), 
-				   fd2info(fd,0)));
+  COMMAND_CALL(self->c,
+	       make_listen_value(make_lsh_fd(conn, "accepted socket", self->e),
+				 sockaddr2info(addr_len,
+					       (struct sockaddr *) &peer), 
+				 fd2info(fd,0)),
+	       &discard_continuation, self->e);
 }
 
 struct io_callback *
-make_listen_callback(struct command_continuation *c,
+make_listen_callback(struct command *c,
 		     struct exception_handler *e)
 {
   NEW(io_listen_callback, self);
@@ -745,6 +746,7 @@ make_listen_callback(struct command_continuation *c,
   return &self->super;
 }
 
+
 /* Connect callback */
 
 /* GABA:
@@ -1101,11 +1103,10 @@ fd2info(struct lsh_fd *fd, int side)
     get = getsockname( fd->fd, (struct sockaddr *)  &sock, &s_len );
   else
     get = getpeername( fd->fd, (struct sockaddr *)  &sock, &s_len );
-
-        
+  
   if (get < 0)  
     {               
-      werror("io.c: getXXXXname failed, %z", STRERROR(errno));
+      werror("io.c: getXXXXname failed %e", errno);
       return NULL;
     }
 
@@ -1277,10 +1278,10 @@ void io_set_nonblocking(int fd)
   int old = fcntl(fd, F_GETFL);
 
   if (old < 0)
-    fatal("io_set_nonblocking: fcntl(F_GETFL) failed, %z", STRERROR(errno));
+    fatal("io_set_nonblocking: fcntl(F_GETFL) failed %e", errno);
   
   if (fcntl(fd, F_SETFL, old | O_NONBLOCK) < 0)
-    fatal("io_set_nonblocking: fcntl(F_SETFL) failed, %z", STRERROR(errno));
+    fatal("io_set_nonblocking: fcntl(F_SETFL) failed %e", errno);
 }
 
 void io_set_blocking(int fd)
@@ -1288,10 +1289,10 @@ void io_set_blocking(int fd)
   int old = fcntl(fd, F_GETFL);
 
   if (old < 0)
-    fatal("io_set_blocking: fcntl(F_GETFL) failed, %z", STRERROR(errno));
+    fatal("io_set_blocking: fcntl(F_GETFL) failed %e", errno);
   
   if (fcntl(fd, F_SETFL, old & ~O_NONBLOCK) < 0)
-    fatal("io_set_blocking: fcntl(F_SETFL) failed, %z", STRERROR(errno));
+    fatal("io_set_blocking: fcntl(F_SETFL) failed %e", errno);
 }
 
 void io_set_close_on_exec(int fd)
@@ -1302,11 +1303,10 @@ void io_set_close_on_exec(int fd)
   int old = fcntl(fd, F_GETFD);
 
   if (old < 0)
-    fatal("io_set_nonblocking: fcntl(F_GETFD) failed, %z", STRERROR(errno));
+    fatal("io_set_nonblocking: fcntl(F_GETFD) failed %e", errno);
   
   if (fcntl(fd, F_SETFD, old | 1) < 0)
-    fatal("Can't set close-on-exec flag for fd %i: %z\n",
-	  fd, STRERROR(errno));
+    fatal("Can't set close-on-exec flag for fd %i %e\n", fd, errno);
 }
 
 
@@ -1407,19 +1407,16 @@ io_connect(struct sockaddr *remote,
 }
 
 struct lsh_fd *
-io_listen(struct sockaddr *local,
-	  socklen_t length,
-	  struct io_callback *callback,
-	  struct exception_handler *e)
+io_bind_sockaddr(struct sockaddr *local,
+		 socklen_t length,
+		 struct exception_handler *e)
 {
   int s = socket(local->sa_family, SOCK_STREAM, 0);
-  struct lsh_fd *fd;
   
   if (s<0)
     return NULL;
 
-  trace("io.c: Listening on fd %i\n", s);
-  
+  trace("io.c: Trying to bind fd %i\n", s);
   io_init_fd(s);
 
   {
@@ -1429,18 +1426,32 @@ io_listen(struct sockaddr *local,
 
   if (bind(s, (struct sockaddr *)local, length) < 0)
     {
+      trace("io.c: bind failed %e\n", errno);
       close(s);
       return NULL;
     }
 
-  if (listen(s, 256) < 0) 
+  return make_lsh_fd(s, "bound socket", e);
+}
+
+/* FIXME: Rename to io_listen. */
+struct lsh_fd *
+io_listen(struct lsh_fd *fd,
+	  struct io_callback *callback)
+{
+  /* For convenience in nested function calls. */
+  if (!fd)
+    return NULL;
+  
+  if (listen(fd->fd, 256) < 0) 
     {
-      close(s);
+      /* Closes the fd and returns failure.
+       * Caller is responsible for checking the return value and raising
+       * a proper exception. */
+      close_fd(fd);
       return NULL;
     }
 
-  fd = make_lsh_fd(s, "listening socket", e);
-
   fd->read = callback;
   lsh_oop_register_read_fd(fd);
 
@@ -1470,43 +1481,28 @@ make_local_info(struct lsh_string *directory,
   }
 }
 
-static void
-safe_popd(int old_cd, const char *directory)
+void
+lsh_popd(int old_cd, const char *directory)
 {
   while (fchdir(old_cd) < 0)
     if (errno != EINTR)
-      fatal("io.c: Failed to cd back from %z (errno = %i): %z\n",
-	    directory, errno, STRERROR(errno));
+      fatal("io.c: Failed to cd back from %z %e\n",
+	    directory, errno);
       
   close(old_cd);
 }
 
-/* Changes the cwd, making sure that it it has reasonable permissions,
- * and that we can change back later. */
-static int
-safe_pushd(const char *directory,
-	   int create)
+int
+lsh_pushd_fd(int dir)
 {
   int old_cd;
-  struct stat sbuf;
 
-  if (create)
-    {  
-      /* First create the directory, in case it doesn't yet exist. */
-      if ( (mkdir(directory, 0700) < 0)
-	   && (errno != EEXIST) )
-	{
-	  werror("io.c: Creating directory %z failed "
-		 "(errno = %i): %z\n", directory, errno, STRERROR(errno));
-	}
-    }
-    
   /* cd to it, but first save old cwd */
 
   old_cd = open(".", O_RDONLY);
   if (old_cd < 0)
     {
-      werror("io.c: open(\".\") failed.\n");
+      werror("io.c: open(`.') failed.\n");
       return -1;
     }
 
@@ -1514,8 +1510,7 @@ safe_pushd(const char *directory,
   while (fchdir(old_cd) < 0)
     if (errno != EINTR)
       {
-	werror("io.c: fchdir(\".\") failed (errno = %i): %z\n",
-	       errno, strerror(errno));
+	werror("io.c: fchdir(`.') failed %e\n", errno);
 	close(old_cd);
 	return -1;
       }
@@ -1525,47 +1520,121 @@ safe_pushd(const char *directory,
    * Even if the directory is chmod:et to zero, or unlinked, we can
    * probably fchdir back to old_cd later. */
 
-  while (chdir(directory) < 0)
+  while (fchdir(dir) < 0)
     if (errno != EINTR)
       {
 	close(old_cd);
 	return -1;
       }
 
-  /* Check that it has reasonable permissions */
-  if (stat(".", &sbuf) < 0)
-    {
-      werror("io.c: Failed to stat \".\" (supposed to be %z).\n"
-	     "  (errno = %i): %z\n", directory, errno, STRERROR(errno));
+  return old_cd;
+}
 
-      safe_popd(old_cd, directory);
+/* Changes the cwd, making sure that it it has reasonable permissions,
+ * and that we can change back later. */
+int
+lsh_pushd(const char *directory,
+	  /* The fd to the directory is stored in *FD, unless fd is
+	   * NULL */
+	  int *result,
+	  int create, int secret)
+{
+  int old_cd;
+  int fd;
+  struct stat sbuf;
+
+  if (create)
+    {  
+      /* First create the directory, in case it doesn't yet exist. */
+      if ( (mkdir(directory, 0700) < 0)
+	   && (errno != EEXIST) )
+	{
+	  werror("io.c: Creating directory %z failed "
+		 "%e\n", directory, errno);
+	}
+    }
+
+  fd = open(directory, O_RDONLY);
+  if (fd < 0)
+    return -1;
+
+  if (fstat(fd, &sbuf) < 0)
+    {
+      werror("io.c: Failed to stat `%z'.\n"
+	     "  %e\n", directory, errno);
+      return -1;
+    }
+  
+  if (!S_ISDIR(sbuf.st_mode))
+    {
+      close(fd);
       return -1;
     }
 
-  if (sbuf.st_uid != getuid())
+  if (secret)
     {
-      werror("io.c: Socket directory %z not owned by user.\n", directory);
+      /* Check that it has reasonable permissions */
+      if (sbuf.st_uid != getuid())
+	{
+	  werror("io.c: Socket directory %z not owned by user.\n", directory);
 
-      safe_popd(old_cd, directory);
-      return -1;
-    }
+	  close(fd);
+	  return -1;
+	}
     
-  if (sbuf.st_mode & (S_IRWXG | S_IRWXO))
-    {
-      werror("io.c: Permission bits on %z are too loose.\n", directory);
+      if (sbuf.st_mode & (S_IRWXG | S_IRWXO))
+	{
+	  werror("io.c: Permission bits on %z are too loose.\n", directory);
 
-            safe_popd(old_cd, directory);
+	  close(fd);
+	  return -1;
+	}
+    }
+  
+  /* cd to it, but first save old cwd */
+
+  old_cd = open(".", O_RDONLY);
+  if (old_cd < 0)
+    {
+      werror("io.c: open('.') failed.\n");
+
+      close(fd);
       return -1;
     }
 
+  /* Test if we are allowed to cd to our current working directory. */
+  while (fchdir(old_cd) < 0)
+    {
+      werror("io.c: fchdir(\".\") failed %e\n", errno);
+      close(fd);
+      close(old_cd);
+      return -1;
+      }
+
+  /* As far as I have been able to determine, all checks for
+   * fchdir:ability is performed at the time the directory was opened.
+   * Even if the directory is chmod:et to zero, or unlinked, we can
+   * probably fchdir back to old_cd later. */
+
+  while (fchdir(fd) < 0)
+    {
+      close(fd);
+      close(old_cd);
+      return -1;
+    }
+
+  if (result)
+    *result = fd;
+  else
+    close(fd);
+  
   return old_cd;
 }
 
 
 struct lsh_fd *
-io_listen_local(struct local_info *info,
-		struct io_callback *callback,
-		struct exception_handler *e)
+io_bind_local(struct local_info *info,
+	      struct exception_handler *e)
 {
   int old_cd;
 
@@ -1593,7 +1662,7 @@ io_listen_local(struct local_info *info,
 
   /* cd to it, but first save old cwd */
 
-  old_cd = safe_pushd(cdir, 1);
+  old_cd = lsh_pushd(cdir, NULL, 1, 1);
   if (old_cd < 0)
     return NULL;
 
@@ -1604,9 +1673,9 @@ io_listen_local(struct local_info *info,
   if ( (unlink(cname) < 0)
        && (errno != ENOENT))
     {
-      werror("io.c: unlink '%S'/'%S' failed (errno = %i): %z\n",
-	     info->directory, info->name, errno, STRERROR(errno));
-      safe_popd(old_cd, cdir);
+      werror("io.c: unlink '%S'/'%S' failed %e\n",
+	     info->directory, info->name, errno);
+      lsh_popd(old_cd, cdir);
       return NULL;
     }
 
@@ -1616,12 +1685,13 @@ io_listen_local(struct local_info *info,
   old_umask = umask(0077);
 
   /* Bind and listen */
-  fd = io_listen( (struct sockaddr *) local, local_length, callback, e);
+  fd = io_bind_sockaddr((struct sockaddr *) local,
+			local_length, e);
   
   /* Ok, now we restore umask and cwd */
   umask(old_umask);
 
-  safe_popd(old_cd, info->directory->data);
+  lsh_popd(old_cd, info->directory->data);
 
   return fd;
 }
@@ -1656,13 +1726,13 @@ io_connect_local(struct local_info *info,
 
   /* cd to it, but first save old cwd */
 
-  old_cd = safe_pushd(cdir, 0);
+  old_cd = lsh_pushd(cdir, NULL, 0, 1);
   if (old_cd < 0)
     return NULL;
   
   fd = io_connect( (struct sockaddr *) addr, addr_length, c, e);
 
-  safe_popd(old_cd, cdir);
+  lsh_popd(old_cd, cdir);
 
   return fd;
 }
@@ -1779,8 +1849,7 @@ close_fd(struct lsh_fd *fd)
       
       if (close(fd->fd) < 0)
 	{
-	  werror("io.c: close failed, (errno = %i): %z\n",
-		 errno, STRERROR(errno));
+	  werror("io.c: close failed %e\n", errno);
 	  EXCEPTION_RAISE(fd->e,
 			  make_io_exception(EXC_IO_CLOSE, fd,
 					    errno, NULL));
@@ -1862,8 +1931,7 @@ close_fd_write(struct lsh_fd *fd)
               /* Try calling shutdown */
               if ( (shutdown (fd->fd, SHUT_WR) < 0)
                    && errno != ENOTSOCK)
-                werror("close_fd_write, shutdown failed, (errno = %i): %z\n",
-                       errno, STRERROR(errno));
+                werror("close_fd_write, shutdown failed, %e\n", errno);
             }
         }
     }
@@ -1956,19 +2024,19 @@ lsh_make_pipe(int *fds)
 {
   if (socketpair(AF_UNIX, SOCK_STREAM, 0, fds) < 0)
     {
-      werror("socketpair failed: %z\n", STRERROR(errno));
+      werror("socketpair failed %e\n", errno);
       return 0;
     }
   trace("Created socket pair. Using fd:s %i <-- %i\n", fds[0], fds[1]);
 
   if (SHUTDOWN_UNIX(fds[0], SHUT_WR_UNIX) < 0)
     {
-      werror("shutdown(%i, SHUT_WR) failed: %z\n", fds[0], STRERROR(errno));
+      werror("shutdown(%i, SHUT_WR) failed %e\n", fds[0], errno);
       goto fail;
     }
   if (SHUTDOWN_UNIX(fds[1], SHUT_RD_UNIX) < 0)
     {
-      werror("shutdown(%i, SHUT_RD_UNIX) failed: %z\n", fds[0], STRERROR(errno));
+      werror("shutdown(%i, SHUT_RD_UNIX) failed %e\n", fds[0], errno);
     fail:
       {
 	int saved_errno = errno;
