@@ -2,7 +2,7 @@
  *
  *
  *
- * $Id: io.h,v 1.90 2002/06/18 07:52:27 nisse Exp $ */
+ * $Id: io.h,v 1.95 2002/08/25 08:14:44 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -27,7 +27,6 @@
 #define LSH_IO_H_INCLUDED
 
 #include "abstract_io.h"
-#include "command.h"
 #include "resource.h"
 #include "write_buffer.h"
 
@@ -305,15 +304,17 @@ io_connect(struct sockaddr *remote,
 	   struct exception_handler *e);
 
 struct lsh_fd *
-io_listen(struct sockaddr *local,
-	  socklen_t length,
-	  struct io_callback *callback,
-	  struct exception_handler *e);
+io_bind_sockaddr(struct sockaddr *local,
+		 socklen_t length,
+		 struct exception_handler *e);
 
 struct lsh_fd *
-io_listen_local(struct local_info *info,
-		struct io_callback *callback,
-		struct exception_handler *e);
+io_listen(struct lsh_fd *fd,
+	  struct io_callback *callback);
+
+struct lsh_fd *
+io_bind_local(struct local_info *info,
+	      struct exception_handler *e);
 
 struct lsh_fd *
 io_connect_local(struct local_info *info,
@@ -321,7 +322,7 @@ io_connect_local(struct local_info *info,
 		 struct exception_handler *e);
 
 struct io_callback *
-make_listen_callback(struct command_continuation *c,
+make_listen_callback(struct command *c,
 		     struct exception_handler *e);
 
 struct lsh_fd *io_read_write(struct lsh_fd *fd,
@@ -337,6 +338,7 @@ struct lsh_fd *io_write(struct lsh_fd *fd,
 			UINT32 block_size,
 			struct lsh_callback *close_callback);
 
+/* Close the fd right away. */
 void close_fd(struct lsh_fd *fd);
 
 /* Stop reading from the fd, and close it as soon as the buffer
@@ -367,6 +369,19 @@ lsh_make_pipe(int *fds);
 int
 lsh_copy_file(int src, int dst);
 
+/* Temporarily changing the current directory. */
+
+int
+lsh_pushd_fd(int dir);
+
+int
+lsh_pushd(const char *directory,
+	  int *fd,
+	  int create, int secret);
+void
+lsh_popd(int old_cd, const char *directory);
+
+
 /* Socket workaround */
 #ifndef SHUTDOWN_WORKS_WITH_UNIX_SOCKETS
 
