@@ -1,6 +1,6 @@
 /* io_commands.c
  *
- * $Id: io_commands.c,v 1.54 2002/07/03 12:46:34 _cvs_pont Exp $
+ * $Id: io_commands.c,v 1.59 2002/08/25 08:19:30 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -85,7 +85,8 @@ DEFINE_COMMAND(io_write_file_command)
 }
 
 struct io_write_file_info *
-make_io_write_file_info(struct lsh_string *name, int flags, int mode, UINT32 block_size)
+make_io_write_file_info(struct lsh_string *name,
+			int flags, int mode, UINT32 block_size)
 {
   NEW(io_write_file_info, self);
   self->name = name;
@@ -96,20 +97,34 @@ make_io_write_file_info(struct lsh_string *name, int flags, int mode, UINT32 blo
   return self;
 }
 
+/* (listen callback fd) */
+DEFINE_COMMAND2(listen_command)
+     (struct command_2 *s UNUSED,
+      struct lsh_object *a1,
+      struct lsh_object *a2,
+      struct command_continuation *c,
+      struct exception_handler *e)
+{
+  CAST_SUBTYPE(command, callback, a1);
+  CAST(lsh_fd, fd, a2);
+
+  if (io_listen(fd, make_listen_callback(callback, e)))
+    COMMAND_RETURN(c, fd);
+  else
+    EXCEPTION_RAISE(e, make_io_exception(EXC_IO_LISTEN,
+					 NULL, errno, NULL));
+}
 
 static struct exception resolve_exception =
 STATIC_EXCEPTION(EXC_RESOLVE, "address could not be resolved");
 
-/* Used by do_listen_callback and any other listen variants. Currently
- * doesn't perform any dns lookups. */
-static void
-do_listen(struct address_info *a,
-	  /* Continuation if listen succeeds. */
-	  struct command_continuation *listen_c,
-	  /* Continuation if accept succeeds. */
-	  struct command_continuation *accept_c,
-	  struct exception_handler *e)
+DEFINE_COMMAND(bind_address_command)
+     (struct command *self UNUSED,
+      struct lsh_object *x,
+      struct command_continuation *c,
+      struct exception_handler *e)
 {
+  CAST(address_info, a, x);
   struct sockaddr *addr;
   socklen_t addr_length;
   
@@ -122,39 +137,32 @@ do_listen(struct address_info *a,
       return;
     }
 
-  fd = io_listen(addr, addr_length,
-		 make_listen_callback(accept_c, e),
-		 e);
+  fd = io_bind_sockaddr(addr, addr_length, e);
   lsh_space_free(addr);
   
-  if (!fd)
+  if (fd)
+    COMMAND_RETURN(c, fd);
+  else
+    /* FIXME: Do we need an EXC_IO_BIND ? */
     EXCEPTION_RAISE(e, make_io_exception(EXC_IO_LISTEN,
 					 NULL, errno, NULL));
-  else
-    COMMAND_RETURN(listen_c, fd);
 }
 
-/* A listen function taking two arguments:
- * (listen callback port).
- *
- * Suitable for handling forwarding requests. NOTE: The calling
- * function has to do all remembering of the fd:s. */
-
-DEFINE_COMMAND2(listen_with_callback)
-     (struct command_2 *s UNUSED,
-      struct lsh_object *a1,
-      struct lsh_object *a2,
+DEFINE_COMMAND(bind_local_command)
+     (struct command *self UNUSED,
+      struct lsh_object *x,
       struct command_continuation *c,
       struct exception_handler *e)
 {
-  CAST_SUBTYPE(command, callback, a1);
-  CAST(address_info, address, a2);
+  CAST(local_info, info, x);
+  struct lsh_fd *fd = io_bind_local(info, e);
 
-  /* No dns lookups */
-  do_listen(address,
-	    c,
-	    make_apply(callback,
-		       &discard_continuation, e), e);
+  if (fd)
+    COMMAND_RETURN(c, fd);
+  else
+    /* FIXME: Do we need an EXC_IO_BIND ? */
+    EXCEPTION_RAISE(e, make_io_exception(EXC_IO_LISTEN,
+					 NULL, errno, NULL));
 }
 
 
@@ -292,80 +300,6 @@ DEFINE_COMMAND2(connect_connection_command)
 }
 
 
-/* GABA:
-   (class
-     (name listen_local)
-     (super command)
-     (vars
-       (info object local_info)))
-*/
-
-static void
-do_listen_local(struct command *s,
-		struct lsh_object *x,
-		struct command_continuation *c,
-		struct exception_handler *e)
-{
-  CAST(listen_local, self, s);
-  CAST_SUBTYPE(command, callback, x);
-  
-  struct lsh_fd *fd
-    = io_listen_local(self->info,
-		      make_listen_callback(make_apply(callback,
-						      &discard_continuation, e),
-					   e),
-		      e);
-  if (!fd)
-    EXCEPTION_RAISE(e, make_io_exception(EXC_IO_LISTEN,
-					 NULL, errno, NULL));
-  else
-    COMMAND_RETURN(c, fd);
-}
-
-struct command *
-make_listen_local(struct local_info *info)
-{
-  NEW(listen_local, self);
-  self->info = info;
-
-  self->super.call = do_listen_local;
-
-  return &self->super;
-}
-
-/* ;; GABA:
-   (class
-     (name connect_local)
-     (super command)
-     (vars
-       (backend object io_backend)))
-*/
-
-#if 0
-static void
-do_connect_local(struct command *self,
-                 struct lsh_object *x,
-                 struct command_continuation *c,
-                 struct exception_handler *e)
-{
-  CAST(local_info, info, x);
-
-  io_connect_local(info,
-		   make_connect_continuation(NULL, c),
-		   e);
-}
-
-struct command *
-make_connect_local(void)
-{
-  NEW(connect_local, self);
-
-  self->call = do_connect_local;
-
-  return self;
-}
-#endif
-
 DEFINE_COMMAND(connect_local_command)
      (struct command *s UNUSED,
       struct lsh_object *a,
