@@ -1,6 +1,6 @@
 /* io_commands.h
  *
- * $Id: io_commands.h,v 1.24 2002/05/15 21:37:11 _cvs_pont Exp $
+ * $Id: io_commands.h,v 1.28 2002/08/26 20:16:57 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -25,7 +25,6 @@
 #ifndef LSH_IO_COMMANDS_H_INCLUDED
 #define LSH_IO_COMMANDS_H_INCLUDED
 
-#include "command.h"
 #include "connection.h"
 #include "io.h"
 
@@ -50,12 +49,15 @@ extern struct command io_write_file_command;
 
 #define IO_WRITE_FILE (&io_write_file_command.super)
 
+extern struct command_2 listen_command;
+#define LISTEN (&listen_command.super.super)
 
-struct command *
-make_listen_with_callback(struct command *callback);
+extern struct command bind_address_command;
+#define BIND (&bind_address_command.super)
+
+extern struct command bind_local_command;
+#define BIND_LOCAL (&bind_local_command.super)
 
-extern struct command_2 listen_with_callback;
-#define LISTEN_CALLBACK (&listen_with_callback.super.super)
 
 struct command *
 make_connect_port(struct address_info *target);
@@ -66,11 +68,13 @@ extern struct command_2 connect_connection_command;
 extern struct command connect_simple_command;
 #define CONNECT_SIMPLE (&connect_simple_command.super)
 
+#if 0
 struct command *
 make_listen_local(struct local_info *info);
 
 struct command *
 make_connect_local(void);
+#endif
 
 extern struct command connect_local_command;
 #define CONNECT_LOCAL (&connect_local_command.super)
