@@ -2,7 +2,7 @@
  *
  * Decode ssh2 keys.
  *
- * $Id: lsh-decode-key.c,v 1.15 2001/10/03 16:12:14 nisse Exp $
+ * $Id: lsh-decode-key.c,v 1.17 2002/08/26 20:14:18 nisse Exp $
  */
 
 #include "digits.h"
@@ -12,14 +12,13 @@
 #include "lsh_argp.h"
 #include "publickey_crypto.h"
 #include "read_file.h"
-#include "rsa.h"
 #include "sexp.h"
 #include "spki.h"
 #include "version.h"
 #include "werror.h"
 #include "xalloc.h"
 
-#include <string.h>
+/* #include <string.h> */
 
 #include <unistd.h>
 #include <fcntl.h>
@@ -188,8 +187,8 @@ int main(int argc, char **argv)
                  O_WRONLY | O_CREAT, 0666);
       if (out < 0)
         {
-          werror("Failed to open file `%S' for writing: %z\n",
-                 options->file, STRERROR(errno));
+          werror("Failed to open file `%S' for writing %e\n",
+                 options->file, errno);
           return EXIT_FAILURE;
         }
     }
@@ -197,8 +196,7 @@ int main(int argc, char **argv)
   input = io_read_file_raw(STDIN_FILENO, 3000);
   if (!input)
     {
-      werror("Failed to read stdin: %z\n",
-             STRERROR(errno));
+      werror("Failed to read stdin %e\n", errno);
       return EXIT_FAILURE;
     }
 
