@@ -2,7 +2,7 @@
  *
  * Reads a (private) key on stdin, and saves it a private and a public file.
  *
- * $Id: lsh-writekey.c,v 1.25 2002/03/17 23:26:30 nisse Exp $ */
+ * $Id: lsh-writekey.c,v 1.26 2002/08/26 20:14:18 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -38,7 +38,7 @@
 
 #include <assert.h>
 #include <errno.h>
-#include <string.h>
+/* #include <string.h> */
 
 #include <fcntl.h>
 #include <sys/stat.h>
@@ -340,8 +340,7 @@ open_file(const struct lsh_string *file)
                 0600);
 
   if (fd < 0)
-    werror("Failed to open `%S'for writing: %z\n",
-           file, STRERROR(errno));
+    werror("Failed to open `%S'for writing %e\n", file, errno);
 
   return fd;
 }
@@ -416,8 +415,7 @@ main(int argc, char **argv)
 
   if (!input)
     {
-      werror("Failed to read key from stdin: %z\n",
-             STRERROR(errno));
+      werror("Failed to read key from stdin %e\n", errno);
       return EXIT_FAILURE;
     }
   
