@@ -2,7 +2,7 @@
  *
  * client main program
  *
- * $Id: lsh.c,v 1.162 2002/05/14 20:58:14 _cvs_pont Exp $ */
+ * $Id: lsh.c,v 1.167 2002/08/29 21:51:11 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -59,7 +59,7 @@
 #include <locale.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <string.h>
+/* #include <string.h> */
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -203,8 +203,7 @@ read_known_hosts(struct lsh_options *options)
   if (fd < 0)
     {
       lsh_string_free(tmp);
-      werror("Failed to open `%z' for reading: %z\n",
-             s, STRERROR(errno));
+      werror("Failed to open `%z' for reading %e\n", s, errno);
       return context;
     }
 
@@ -214,8 +213,7 @@ read_known_hosts(struct lsh_options *options)
   
   if (!contents)
   {
-    werror("Failed to read known_hosts file: %z\n",
-           STRERROR(errno));
+    werror("Failed to read known_hosts file %e\n", errno);
     close(fd);
     return context;
   }
@@ -273,8 +271,7 @@ read_user_keys(struct lsh_options *options)
   fd = open(name, O_RDONLY);
   if (fd < 0)
     {
-      werror("Failed to open `%z' for reading: %z\n",
-             name, STRERROR(errno));
+      werror("Failed to open `%z' for reading %e\n", name, errno);
       lsh_string_free(tmp);
 
       return make_object_list(0, -1);
@@ -286,8 +283,7 @@ read_user_keys(struct lsh_options *options)
 
   if (!contents)
     {
-      werror("Failed to read private key file: %z\n",
-             STRERROR(errno));
+      werror("Failed to read private key file %e\n", errno);
       close(fd);
 
       return make_object_list(0, -1);
@@ -311,8 +307,8 @@ read_user_keys(struct lsh_options *options)
       alist_select_l(mac, options->algorithms->algorithms,
 		     2, ATOM_HMAC_SHA1, ATOM_HMAC_MD5, -1);
       alist_select_l(crypto, options->algorithms->algorithms,
-		     3, ATOM_3DES_CBC, ATOM_BLOWFISH_CBC,
-		     ATOM_RIJNDAEL_CBC_LOCAL, -1);
+		     4, ATOM_3DES_CBC, ATOM_BLOWFISH_CBC,
+		     ATOM_TWOFISH_CBC, ATOM_AES256_CBC, -1);
       
       expr = spki_pkcs5_decrypt(mac, crypto,
                                 options->super.tty,
@@ -762,6 +758,7 @@ main_options[] =
     0, "", CLIENT_ARGP_ACTION_GROUP },
   { "gateway", 'G', NULL, 0, "Setup a local gateway", 0 },
 
+#if WITH_X11_FORWARD
   /* FIXME: Perhaps this should be moved from lsh.c to client.c? It
    * doesn't work with lshg. Or perhaps that can be fixed?
    * About the same problem applies to -R. */
@@ -769,6 +766,7 @@ main_options[] =
   { "x11-forward", 'x', NULL, 0, "Enable X11 forwarding.", CLIENT_ARGP_MODIFIER_GROUP },
   { "no-x11-forward", 'x' | ARG_NOT, NULL, 0,
     "Disable X11 forwarding (default).", 0 },
+#endif
   
   { NULL, 0, NULL, 0, NULL, 0 }
 };
@@ -887,21 +885,23 @@ main_argp_parser(int key, char *arg, struct argp_state *state)
 	  }
 	if (s)
 	  {
+	    static const struct report_exception_info report =
+	      STATIC_REPORT_EXCEPTION_INFO(EXC_IO, EXC_IO,
+					   "Writing new ACL: ");
+	    
 	    struct lsh_fd *f
 	      = io_write_file(s,
 			      O_CREAT | O_APPEND | O_WRONLY,
 			      0600, 500, NULL,
 			      make_report_exception_handler
-			      (make_report_exception_info(EXC_IO, EXC_IO,
-							  "Writing new ACL: "),
+			      (&report,
 			       &default_exception_handler,
 			       HANDLER_CONTEXT));
 	    if (f)
 	      self->capture_file = &f->write_buffer->super;
 	    else
 	      {
-		werror("Failed to open '%z' (errno = %i): %z.\n",
-		       s, errno, STRERROR(errno));
+		werror("Failed to open '%z' %e.\n", s, errno);
 	      }
 	  }
 	lsh_string_free(tmp);
@@ -931,8 +931,7 @@ main_argp_parser(int key, char *arg, struct argp_state *state)
 	    }
 	      
 	  client_add_action(&self->super,
-			    make_gateway_setup
-			    (make_listen_local(gateway)));
+			    make_gateway_setup(gateway));
 	}
 
       if (object_queue_is_empty(&self->super.actions))
@@ -988,7 +987,9 @@ main_argp_parser(int key, char *arg, struct argp_state *state)
       }      
       
     CASE_FLAG('G', start_gateway);
+#if WITH_X11_FORWARD
     CASE_FLAG('x', super.with_x11);
+#endif
     }
 
   return 0;
