@@ -1,6 +1,6 @@
 /* lsh.h
  *
- * $Id: lsh.h,v 1.25 2002/03/15 09:12:37 nisse Exp $ */
+ * $Id: lsh.h,v 1.26 2002/08/25 08:20:21 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -107,6 +107,13 @@ struct abstract_write;
 /* client_x11.c */
 struct client_x11_display;
 
+/* command.h */
+struct command_continuation;
+struct command;
+struct command_2;
+struct command_3;
+struct command_4;
+
 /* connection.h */
 struct ssh_connection;
 
