@@ -2,7 +2,7 @@
  *
  * main proxy program.
  *
- * $Id: lsh_proxy.c,v 1.32 2002/06/27 17:19:22 nisse Exp $ */
+ * $Id: lsh_proxy.c,v 1.33 2002/08/24 22:21:30 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -469,7 +469,7 @@ DEFINE_COMMAND2(proxy_destination)
      (expr 
        (lambda (options)
          ; accept a connection
-	 (listen_callback
+	 (listen
 	   (lambda (client_addr)
 	     ; address of accepted connection
 	     (services
@@ -478,7 +478,7 @@ DEFINE_COMMAND2(proxy_destination)
 	         (handshake_server options)   ; callback to perform server side handshake
 		 (handshake_client options)   ; callback to perform client side handshake
 		 client_addr)))
-	   (options2local options)))) )
+	   (bind (options2local options)) ))))
 
 	     
 */
