@@ -2,7 +2,7 @@
  *
  * main server program.
  *
- * $Id: lshd.c,v 1.141 2002/07/05 20:03:02 nisse Exp $ */
+ * $Id: lshd.c,v 1.144 2002/08/26 20:14:18 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -80,7 +80,7 @@ struct command_2 close_on_sighup;
 #include <errno.h>
 #include <locale.h>
 #include <stdio.h>
-#include <string.h>
+/* #include <string.h> */
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -89,9 +89,6 @@ struct command_2 close_on_sighup;
 #include <unistd.h>
 #endif
 
-/* Disabled in the 1.4 series. */
-#undef WITH_X11_FORWARD
-#define WITH_X11_FORWARD 0
 
 /* Option parsing */
 
@@ -301,6 +298,7 @@ DEFINE_COMMAND(options2local)
       struct exception_handler *e UNUSED)
 {
   CAST(lshd_options, options, a);
+  /* FIXME: Call bind already here? */
   COMMAND_RETURN(c, options->local);
 }
 
@@ -346,8 +344,7 @@ do_kill_pid_file(struct resource *s)
     {
       self->super.alive = 0;
       if (unlink(self->file) < 0)
-	werror("Unlinking pidfile failed (errno = %i): %z\n",
-	       errno, STRERROR(errno));
+	werror("Unlinking pidfile failed %e\n", errno);
     }
 }
 
@@ -421,7 +418,6 @@ DEFINE_COMMAND(options2tcp_wrapper)
 #if WITH_TCPWRAPPERS
   CAST(lshd_options, options, a);
 
-
   if (options->tcp_wrapper_name) 
     COMMAND_RETURN(c, 
 		   make_tcp_wrapper(
@@ -873,14 +869,14 @@ main_argp =
      (expr (lambda (options)
              (let ((keys (options2keys options)))
 	       (close_on_sighup options
-	         (listen_callback
+	         (listen
 	           (lambda (lv)
     	             (services (connection_handshake
     	           		  handshake
     	           		  (kexinit_filter init keys)
     	           		  keys 
 				  (options2tcp_wrapper options lv))))
-	           (options2local options) ))))))
+	           (bind (options2local options)) ))))))
 */
 
 
@@ -978,8 +974,7 @@ main(int argc, char **argv)
               
             case -1:
               /* Error */
-              werror("background_process: fork failed (errno = %i): %z\n",
-                     errno, STRERROR(errno));
+              werror("background_process: fork failed %e\n", errno);
               break;
               
             default:
