@@ -2,7 +2,7 @@
  *
  * A read handler for reading an entire file as a string.
  *
- * $Id: read_base64.c,v 1.3 2001/10/02 20:53:19 nisse Exp $ */
+ * $Id: read_base64.c,v 1.4 2002/08/27 16:45:25 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -26,6 +26,7 @@
 #include "read_file.h"
 
 #include "digits.h"
+#include "format.h"
 #include "werror.h"
 #include "xalloc.h"
 
@@ -68,7 +69,7 @@ do_read_base64(struct read_handler **h,
       if (base64_decode(&self->state, TERMINATOR)
 	  == BASE64_END)
 	{
-	  self->buffer->length = self->pos;
+	  lsh_string_trunc(self->buffer, self->pos);
 	  A_WRITE(self->c, self->buffer);
 	}
       else
