@@ -2,7 +2,7 @@
  *
  * A read handler for reading an entire file as a string.
  *
- * $Id: read_file.c,v 1.3 2001/09/27 12:11:47 nisse Exp $ */
+ * $Id: read_file.c,v 1.4 2002/08/27 16:45:44 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -25,6 +25,7 @@
 
 #include "read_file.h"
 
+#include "format.h"
 #include "werror.h"
 #include "xalloc.h"
 
@@ -60,7 +61,7 @@ do_read_file(struct read_handler **h,
   if (!available)
     {
       /* EOF reached */
-      self->buffer->length = self->pos;
+      lsh_string_trunc(self->buffer, self->pos);
 	  
       A_WRITE(self->c, self->buffer);
       self->buffer = NULL;
