@@ -2,7 +2,7 @@
  *
  * Handle child processes.
  *
- * $Id: reaper.c,v 1.23 2002/03/15 09:12:37 nisse Exp $
+ * $Id: reaper.c,v 1.24 2002/08/26 20:14:18 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -31,9 +31,9 @@
 #include "xalloc.h"
 
 #include <assert.h>
-#include <string.h>
-
 #include <errno.h>
+/* #include <string.h> */
+
 #include <signal.h>
 #include <sys/types.h>
 #include <sys/wait.h>
@@ -127,8 +127,7 @@ do_reaper_callback(struct lsh_callback *s)
 	  /* No more child processes */
 	  return;
 	default:
-	  fatal("reaper.c: waitpid failed (errno = %i), %z\n",
-		errno, STRERROR(errno));
+	  fatal("reaper.c: waitpid failed %e\n", errno);
 	}
     }
 }
