@@ -2,7 +2,7 @@
  *
  * System dependant password related functions.
  *
- * $Id: server_password.c,v 1.31 2000/10/15 20:22:26 nisse Exp $
+ * $Id: server_password.c,v 1.33 2001/08/21 11:12:43 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -53,18 +53,19 @@ do_authenticate(struct userauth *s,
 {
   CAST(userauth_password, self, s);
   
-  struct lsh_string *password = NULL;
   int change_passwd;
   
   username = utf8_to_local(username, 1, 1);
   if (!username)
     {
-      PROTOCOL_ERROR(e, "Invalid utf8 in password.");
+      PROTOCOL_ERROR(e, "Invalid utf8 in username.");
       return;
     }
 
   if (parse_boolean(args, &change_passwd))
     {
+      struct lsh_string *password = NULL;
+      
       if (change_passwd)
 	{
 	  static const struct exception passwd_change_not_implemented
@@ -103,15 +104,15 @@ do_authenticate(struct userauth *s,
 	    }
 
 	  USER_VERIFY_PASSWORD(user, password, c, e);
+	  return;
 	}
+      if (password)
+	lsh_string_free(password);
     }
   
   /* Request was invalid */
   lsh_string_free(username);
-
-  if (password)
-    lsh_string_free(password);
-
+  
   PROTOCOL_ERROR(e, "Invalid password USERAUTH message.");
 }
 
