@@ -1,6 +1,6 @@
 /* server_session.c
  *
- * $Id: server_session.c,v 1.92 2002/07/05 20:03:02 nisse Exp $
+ * $Id: server_session.c,v 1.97 2002/08/27 17:17:12 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -41,7 +41,7 @@
 
 /* For debug */
 
-#include <string.h>
+/* #include <string.h> */
 #if HAVE_UNISTD_H
 #include <unistd.h>
 #endif
@@ -53,9 +53,6 @@
 
 #include "server_session.c.x"
 
-/* Disabled in the 1.4 series. */
-#undef WITH_X11_FORWARD
-#define WITH_X11_FORWARD 0
 
 /* Session */
 /* GABA:
@@ -77,9 +74,12 @@
        ; X11 forwarding.
        (x11 object server_x11_info)
        
-       ; value of the TERM environment variable
+       ; Value of the TERM environment variable
        (term string)
 
+       ; Value for the SSH_CLIENT environment variable.
+       (client string)
+       
        ; Child process's stdio 
        (in object lsh_fd)
        (out object lsh_fd)
@@ -169,6 +169,7 @@ make_server_session(UINT32 initial_window,
 
   self->pty = NULL;
   self->term = NULL;
+  self->client = NULL;
   
   self->in = NULL;
   self->out = NULL;
@@ -380,8 +381,7 @@ make_pty(struct pty_info *pty, int *in, int *out, int *err)
       
       if ((out[0] = dup(pty->master)) < 0)
         {
-          werror("make_pty: duping master pty to stdout failed (errno = %i): %z\n",
-                 errno, STRERROR(errno));
+          werror("make_pty: duping master pty to stdout failed %e\n", errno);
 
           return 0;
         }
@@ -545,19 +545,23 @@ init_spawn_info(struct spawn_info *info, struct server_session *session,
 
   if (info->peer)
     {
-      env[i].name ="SSH_CLIENT";
+      /* Save string in the session object, so that it can be garbage
+       * collected properly. */
+      assert(!session->client);
       
       if (session->super.connection->local)
-	env[i].value = ssh_format("%lS %di %di", 
-				  info->peer->ip,
-				  info->peer->port,
-				  session->super.connection->local->port
-				  );
+	session->client = ssh_format("%lS %di %di", 
+				      info->peer->ip,
+				      info->peer->port,
+				      session->super.connection->local->port);
       else
-	env[i].value = ssh_format("%lS %di UNKNOWN", 
-				  info->peer->ip,
-				  info->peer->port
-				  );	
+	session->client = ssh_format("%lS %di UNKNOWN", 
+				     info->peer->ip,
+				     info->peer->port
+				     );
+      env[i].name ="SSH_CLIENT";
+      env[i].value = session->client;
+
       i++;
     }
 
@@ -917,6 +921,7 @@ do_x11_req(struct channel_request *s UNUSED,
       if (session->x11 || session->process
 	  || !(session->x11 = server_x11_setup(channel,
 					       channel->connection->user,
+					       single,
 					       protocol_length, protocol,
 					       cookie_length, cookie,
 					       screen, c, e)))
@@ -925,8 +930,7 @@ do_x11_req(struct channel_request *s UNUSED,
 	  EXCEPTION_RAISE(e, &x11_request_failed);
 	}
       else
-	{
-	  
+	{	  
 	  return;
 	}
     }
