@@ -11,6 +11,8 @@
 #include <stdio.h>
 #include <stdlib.h>
 
+#include <unistd.h>
+
 void
 werror(const char *format, ...)
 {
@@ -38,3 +40,18 @@ fatal(const char *format, ...)
 
   exit(EXIT_FAILURE);
 }
+
+void
+_fatal(const char *format, ...)
+{
+  va_list args;
+
+  va_start(args, format);
+  
+  fprintf(stderr, "%s: ", werror_program_name);
+  vfprintf(stderr, format, args);
+
+  va_end(args);
+
+  _exit(EXIT_FAILURE);
+}
