@@ -1,52 +1,30 @@
 # Helper functions for the test scripts.
 
-# echo srcdir = $srcdir
-
-# Make sure we have a randomness genereetor
-LSH_YARROW_SEED_FILE="`pwd`/yarrow-seed-file"
-export LSH_YARROW_SEED_FILE
-
-if [ -s "$LSH_YARROW_SEED_FILE" ] ; then : ; else
-    echo "Creating seed file $LSH_YARROW_SEED_FILE"
-    ../lsh-make-seed --sloppy -q -o "$LSH_YARROW_SEED_FILE"
-fi
-
-if [ -z "$LSHD_FLAGS" ] ; then
-    LSHD_FLAGS='-q --enable-core'
-fi
-
-if [ -z "$LSH_FLAGS" ] ; then
-    LSH_FLAGS=-q
-fi
-
-if [ -z "$LSHG_FLAGS" ] ; then
-    LSHG_FLAGS=-q
-fi
-
-if [ -z "$HOSTKEY" ] ; then
-    HOSTKEY=$srcdir/key-1.private
-fi
-
-if [ -z "$PIDFILE" ] ; then
-    PIDFILE=`pwd`/lshd.$$.pid
-fi
-
-INTERFACE=127.0.0.1
-
-# if [ -z "$USERKEY" ] ; then
-#     USERKEY=$srcdir/key-1.private
-# fi
-
 # Any error count as failure.
 set -e
 
+# echo srcdir = $srcdir
+
+: ${TEST_HOME:=`pwd`/home}
+: ${LSH_YARROW_SEED_FILE:="$TEST_HOME/.lsh/yarrow-seed-file"}
+
+# For lsh-authorize
+: ${SEXP_CONV:="`pwd`/../sexp-conv"}
+
+export LSH_YARROW_SEED_FILE SEXP_CONV
+
+: ${LSHD_FLAGS:='-q --enable-core'}
+: ${LSH_FLAGS:=-q}
+: ${LSHG_FLAGS:=-q}
+: ${HOSTKEY:="$srcdir/key-1.private"}
+: ${PIDFILE:="`pwd`/lshd.$$.pid"}
+: ${INTERFACE:=127.0.0.1}
+
 PORT=11147
 ATEXIT='set +e'
 
-# Starting with EXIT_FAILURE and changing it to EXIT_SUCCESS on
-# success is right, as long as each test script only performs one
-# test. If there are several tests, it would be better to set it to
-# EXIT_SUCCESS and change it as soon as one test fails.
+# We start with EXIT_FAILURE, and changing it to EXIT_SUCCESS only if
+# test_success is invoked.
 
 test_result=1
 
@@ -60,13 +38,13 @@ test_success () {
     exit
 }
 
-werror () {
-    echo 1>&2 "$1"
+test_skip () {
+    test_result=77
+    exit
 }
 
-die () {
-    werror "$1"
-    test_fail
+check_x11_support () {
+    ../lsh --help | grep 'x11-forward' >/dev/null || test_skip
 }
 
 trap 'eval "$ATEXIT ; exit \$test_result"' 0
@@ -83,7 +61,8 @@ spawn_lshd () {
     # Note that --daemon not only forks into the background, it also changes
     # the cwd, uses syslog, etc.
     
-    ../lshd -h $HOSTKEY --interface=$INTERFACE -p $PORT $LSHD_FLAGS \
+    HOME="$TEST_HOME" ../lshd -h $HOSTKEY --interface=$INTERFACE \
+	-p $PORT $LSHD_FLAGS \
 	--pid-file $PIDFILE --daemon --no-syslog "$@"
 
     # lshd may catch the ordinary TERM signal, leading to timing
@@ -108,20 +87,21 @@ spawn_lshd () {
 run_lsh () {
     cmd="$1"
     shift
-    echo "$cmd" | ../lsh $LSH_FLAGS -nt --sloppy-host-authentication \
+    echo "$cmd" | HOME="$TEST_HOME" ../lsh $LSH_FLAGS -nt \
+	--sloppy-host-authentication \
 	--capture-to /dev/null -z -p $PORT "$@" localhost
 
 }
 
 exec_lsh () {
-    ../lsh $LSH_FLAGS -nt --sloppy-host-authentication \
+    HOME="$TEST_HOME" ../lsh $LSH_FLAGS -nt --sloppy-host-authentication \
 	--capture-to /dev/null -z -p $PORT localhost "$@"
 }
 
 # FIXME: Use -B
 spawn_lsh () {
     # echo spawn_lsh "$@"
-    ../lsh $LSH_FLAGS -nt --sloppy-host-authentication \
+    HOME="$TEST_HOME" ../lsh $LSH_FLAGS -nt --sloppy-host-authentication \
 	--capture-to /dev/null -z -p $PORT "$@" -N localhost &
     at_exit "kill $!"
 }
