@@ -2,7 +2,7 @@
  *
  * User-related functions on UN*X
  *
- * $Id: unix_user.c,v 1.52.2.1 2003/09/20 07:30:23 nisse Exp $
+ * $Id: unix_user.c,v 1.55 2002/08/27 17:17:03 nisse Exp $
  */
 
 /* lsh, an implementation of the ssh protocol
@@ -156,8 +156,8 @@ kerberos_check_pw(struct unix_user *user, struct lsh_string *pw,
   if (access(user->ctx->pw_helper, X_OK) < 0)
     {
       /* No help available */
-      werror("Password helper program '%z' not available (errno = %d): %z\n",
-	     user->ctx->pw_helper, errno, STRERROR(errno));
+      werror("Password helper program '%z' not available %e\n",
+	     user->ctx->pw_helper, errno);
       return 0;
     }
   
@@ -172,7 +172,7 @@ kerberos_check_pw(struct unix_user *user, struct lsh_string *pw,
   switch (child)
     {
     case -1:
-      werror("kerberos_check_pw: fork failed: %z\n", STRERROR(errno));
+      werror("kerberos_check_pw: fork failed %e\n", errno);
       return 0;
 
     case 0:
@@ -432,7 +432,7 @@ do_read_file(struct lsh_user *u,
   /* out[0] for reading, out[1] for writing */
   int out[2];
 
-  uid_t me = getuid();
+  uid_t me = geteuid();
 
   /* There's no point trying to read other user's files unless we're
    * root. */
@@ -449,8 +449,7 @@ do_read_file(struct lsh_user *u,
   if (stat(lsh_get_cstring(f), &sbuf) < 0)
     {
       if (errno != ENOENT)
-	werror("io_read_user_file: Failed to stat %S (errno = %i): %z\n",
-	       f, errno, STRERROR(errno));
+	werror("io_read_user_file: Failed to stat %S %e\n", f, errno);
  
       lsh_string_free(f);
 
@@ -509,14 +508,12 @@ do_read_file(struct lsh_user *u,
 	int fd;
 	close(out[0]);
 
-	/* FIXME: Use seteuid instead? */
-	if ( (me != user->super.uid) && (setuid(user->super.uid) < 0) )
+	if ( (me != user->super.uid) && (seteuid(user->super.uid) < 0) )
 	  {
-	    werror("unix_user.c: do_read_file: setuid failed (errno = %i): %z\n",
-		   errno, STRERROR(errno));
+	    werror("unix_user.c: do_read_file: setuid failed %e\n", errno);
 	    _exit(EXIT_FAILURE);
 	  }
-	assert(user->super.uid == getuid());
+	assert(user->super.uid == geteuid());
 	
 	fd = open(lsh_get_cstring(f), O_RDONLY);
 
@@ -525,12 +522,12 @@ do_read_file(struct lsh_user *u,
 
 	if (fstat(fd, &sbuf) < 0)
 	  {
-	    werror("unix_user.c: do_read_file: fstat failed (errno = %i): %z\n",
-		   errno, STRERROR(errno));
+	    werror("unix_user.c: do_read_file: fstat failed %e\n", errno);
 	    _exit(EXIT_FAILURE);
 	  }
 
-	x = check_user_permissions(&sbuf, lsh_get_cstring(f), user->super.uid, secret);
+	x = check_user_permissions(&sbuf, lsh_get_cstring(f),
+				   user->super.uid, secret);
 
 	if (x)
 	  {
@@ -567,15 +564,13 @@ chdir_home(struct unix_user *user)
   if (user->home)
     {
       if (chdir(lsh_get_cstring(user->home)) < 0)
-	werror("chdir to home directory `%S' failed (errno = %i): %z\n",
-	       user->home, errno, STRERROR(errno));
+	werror("chdir to home directory `%S' failed %e\n", user->home, errno);
       else
 	return 1;
     }
   if (chdir("/") < 0)
     {
-      werror("chdir to `/' failed (errno = %i): %z\n",
-	     errno, STRERROR(errno));
+      werror("chdir to `/' failed %e\n", errno);
       return 0;
     }
   else
@@ -712,8 +707,7 @@ exec_shell(struct unix_user *user, struct spawn_info *info)
   else
     execve(PREFIX "/sbin/lsh-execuv", (char **) argv, (char **) envp);
 
-  werror("unix_user: exec failed (errno = %i): %z\n",
-	 errno, STRERROR(errno));
+  werror("unix_user: exec failed %e\n", errno);
   _exit(EXIT_FAILURE);
 }
 
@@ -721,8 +715,7 @@ static void
 safe_close(int fd)
 {
   if (fd != -1 && close(fd) < 0)
-    werror("close failed (errno = %i): %z\n",
-	   errno, STRERROR(errno));
+    werror("close failed %e\n", errno);
 }
 
 static struct lsh_process *
@@ -744,7 +737,7 @@ do_spawn(struct lsh_user *u,
   child = fork();
   if (child < 0)
     {
-      werror("fork failed: %z\n", STRERROR(errno));
+      werror("unix_user: do_spawn: fork failed %e\n", errno);
       safe_close(sync[0]); safe_close(sync[1]);
 
       safe_close(info->in[0]);  safe_close(info->in[1]);
@@ -810,9 +803,9 @@ do_spawn(struct lsh_user *u,
       trace("do_spawn: child process\n");
       if (!chdir_home(user))
 	_exit(EXIT_FAILURE);
-
-      trace("do_spawn: child after chdir\n");
       
+      trace("do_spawn: child after chdir\n");
+
       /* We want to be a process group leader */
       if (setsid() < 0)
 	{
@@ -820,7 +813,7 @@ do_spawn(struct lsh_user *u,
 		 "   %e\n", errno);
 	  _exit(EXIT_FAILURE);
 	}
-
+      
 #if WITH_PTY_SUPPORT
       if (info->pty)
 	{
