@@ -2,7 +2,7 @@
  *
  *
  *
- * $Id: werror.c,v 1.65 2001/12/12 18:18:49 nisse Exp $ */
+ * $Id: werror.c,v 1.67 2002/08/26 20:14:17 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -534,6 +534,16 @@ werror_vformat(const char *f, va_list args)
 		else
 		  werror_write(strlen(s), s);
 		
+		break;
+	      }
+	    case 'e':
+	      { /* errno specifier */
+		int e = va_arg(args, int);
+		werror_cstring("(errno = ");
+		werror_decimal(e);
+		werror_cstring("): ");
+		werror_cstring(STRERROR(errno));
+
 		break;
 	      }
 	    default:
@@ -546,6 +556,18 @@ werror_vformat(const char *f, va_list args)
     }
 }
 
+/* Unconditionally display message. */
+static void
+werror_format(const char *format, ...) 
+{
+  va_list args;
+
+  va_start(args, format);
+  werror_vformat(format, args);
+  va_end(args);
+  werror_flush();
+}
+
 void
 werror(const char *format, ...) 
 {
@@ -614,6 +636,11 @@ verbose(const char *format, ...)
     }
 }
 
+#define FATAL_SLEEP 0
+#ifndef FATAL_SLEEP
+# define FATAL_SLEEP 0
+#endif
+
 void
 fatal(const char *format, ...) 
 {
@@ -624,6 +651,11 @@ fatal(const char *format, ...)
   va_end(args);
   werror_flush();
 
+#if FATAL_SLEEP
+  werror_format("attach gdb to process %i. Going to sleep...\n", getpid());
+  for (;;)
+    sleep(4711);
+#endif
 #if WITH_GCOV
   exit(255);
 #else
