@@ -2,7 +2,7 @@
  *
  * Xauth parsing.
  *
- * $Id: xauth.c,v 1.7 2001/10/26 14:36:34 nisse Exp $ */
+ * $Id: xauth.c,v 1.8 2002/08/27 16:49:32 nisse Exp $ */
 
 /* lsh, an implementation of the ssh protocol
  *
@@ -199,7 +199,7 @@ read_file(int fd, UINT32 limit)
       else i += res;
     }
 
-  s->length = i;
+  lsh_string_trunc(s, i);
   return s;
 }
 
